

export const index = 45;
let component_cache;
export const component = async () => component_cache ??= (await import('../entries/pages/watch/_page.svelte.js')).default;
export const imports = ["_app/immutable/nodes/45.BON9_ALu.js","_app/immutable/chunks/BsAB9Z30.js","_app/immutable/chunks/IHki7fMi.js","_app/immutable/chunks/DXcMniHh.js"];
export const stylesheets = [];
export const fonts = [];
